==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationMutualTLSFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PeerAuthenticationMutualTLSFluentImpl<A extends PeerAuthenticationMutualTLSFluent<A>> extends BaseFluent<A> implements PeerAuthenticationMutualTLSFluent<A>{
  public PeerAuthenticationMutualTLSFluentImpl() {
  }
  public PeerAuthenticationMutualTLSFluentImpl(PeerAuthenticationMutualTLS instance) {
    this.withMode(instance.getMode()); 
  }
  private PeerAuthenticationMutualTLSMode mode;
  public PeerAuthenticationMutualTLSMode getMode() {
    return this.mode;
  }
  public A withMode(PeerAuthenticationMutualTLSMode mode) {
    this.mode=mode; return (A) this;
  }
  public Boolean hasMode() {
    return this.mode != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PeerAuthenticationMutualTLSFluentImpl that = (PeerAuthenticationMutualTLSFluentImpl) o;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mode,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mode != null) { sb.append("mode:"); sb.append(mode); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationMutualTLSFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PeerAuthenticationMutualTLSFluentImpl<A extends PeerAuthenticationMutualTLSFluent<A>> extends BaseFluent<A> implements PeerAuthenticationMutualTLSFluent<A>{
  public PeerAuthenticationMutualTLSFluentImpl() {
  }
  public PeerAuthenticationMutualTLSFluentImpl(PeerAuthenticationMutualTLS instance) {
    if (instance != null) {
      this.withMode(instance.getMode());
    }
  }
  private PeerAuthenticationMutualTLSMode mode;
  public PeerAuthenticationMutualTLSMode getMode() {
    return this.mode;
  }
  public A withMode(PeerAuthenticationMutualTLSMode mode) {
    this.mode=mode; return (A) this;
  }
  public Boolean hasMode() {
    return this.mode != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PeerAuthenticationMutualTLSFluentImpl that = (PeerAuthenticationMutualTLSFluentImpl) o;
    if (!java.util.Objects.equals(mode, that.mode)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mode,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mode != null) { sb.append("mode:"); sb.append(mode); }
    sb.append("}");
    return sb.toString();
  }
  
}
